Module harness

Module harness 

Harness session environment detection. Harness session environment detection shared across Ito crates.

Structs

HarnessSessionEnv
Resolved harness session environment.

Enums

HarnessKind
Ito harness identifiers inferred from session environment variables.

Constants

HARNESS_SESSION_ENV_VARS
Environment variables that Ito checks for harness session context, in precedence order.

Functions

detect_harness_name
Detect the current harness canonical name from session environment variables.
resolve_harness_session_env
Resolve harness session environment from the current process.
resolve_harness_session_id
Resolve the first configured harness session id from the current process.