pub fn parse_spec_id(input: &str) -> Result<ParsedSpecId, IdParseError>Expand description
Parse a spec identifier.
This is intentionally permissive: any non-empty directory name is accepted as a spec id.
pub fn parse_spec_id(input: &str) -> Result<ParsedSpecId, IdParseError>Parse a spec identifier.
This is intentionally permissive: any non-empty directory name is accepted as a spec id.