read_to_string_or_default

Function read_to_string_or_default 

pub fn read_to_string_or_default(path: &Path) -> String
Read a file into a string, returning an empty string on error.

This is intentionally lossy and should be used for best-effort output only.