Module paths

Module paths 

Canonical .ito/ path builders. Canonical Ito path builders.

These helpers consistently build paths under an Ito root directory.

Functions

archive_changes_dir
Return the directory used by ito archive for archived change artifacts.
change_dir
Return the on-disk directory for a specific change.
change_meta_path
Return the path to a change’s metadata file.
change_specs_dir
Return the specs/ directory within a change directory.
changes_archive_dir
Return the archive directory for changes (changes/archive/).
changes_dir
Return the changes/ directory under the Ito root.
default_ito_root
Canonical .ito/ path builders.
modules_dir
Return the modules/ directory under the Ito root.
spec_markdown_path
Return the canonical path to a spec’s markdown file (spec.md).
specs_dir
Return the specs/ directory under the Ito root.